summaryrefslogtreecommitdiffhomepage
path: root/test/util/pty_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'test/util/pty_util.h')
-rw-r--r--test/util/pty_util.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/util/pty_util.h b/test/util/pty_util.h
index 0722da379..dff6adab5 100644
--- a/test/util/pty_util.h
+++ b/test/util/pty_util.h
@@ -21,11 +21,11 @@
namespace gvisor {
namespace testing {
-// Opens the slave end of the passed master as R/W and nonblocking.
-PosixErrorOr<FileDescriptor> OpenSlave(const FileDescriptor& master);
+// Opens the replica end of the passed main as R/W and nonblocking.
+PosixErrorOr<FileDescriptor> OpenReplica(const FileDescriptor& main);
-// Get the number of the slave end of the master.
-PosixErrorOr<int> SlaveID(const FileDescriptor& master);
+// Get the number of the replica end of the main.
+PosixErrorOr<int> ReplicaID(const FileDescriptor& main);
} // namespace testing
} // namespace gvisor